@@ -279,7 +279,7 @@ sub stmt_placeholder_to_value {
 sub alias {
     my ( $sf, $sql, $type, $identifier, $default ) = @_;
     if ( defined $default ) { # && ! $sf->{o}{G}{quote_identifiers} ) {
-        if ( $sf->{i}{driver} eq 'Pg' ) {
+        if ( $sf->{i}{driver} =~ /^(?:Pg|Informix)\z/ ) {
             $default = lc $default;
         }
         elsif ( $sf->{i}{driver} =~ /^(?:Firebird|DB2)\z/ ) {
@@ -305,6 +305,34 @@ sub alias {
 }
 
 
+sub prepare_identifier {
+    my ( $sf, @id ) = @_;
+    if ( $sf->{o}{G}{quote_identifiers} ) {
+        my $quote = $sf->{d}{identifier_quote_char};
+        for ( @id ) {
+            if ( ! defined ) {
+                next;
+            }
+            s/$quote/$quote$quote/g;
+            $_ = qq{$quote$_$quote};
+        }
+    }
+#    my $catalog = ( @id >= 3 ) ? shift @id : undef;        # catalog not used (if used, uncomment also catalog_location and catalog_name_sep)
+    my $quoted_id = join '.', grep { defined } @id;
+#    if ( $catalog ) {
+#        if ( $quoted_id ) {
+#            $quoted_id = ( $sf->{d}{catalog_location} == 2 )
+#                ? $quoted_id . $sf->{d}{catalog_name_sep} . $catalog
+#                : $catalog   . $sf->{d}{catalog_name_sep} . $quoted_id;
+#        } else {
+#            $quoted_id = $catalog;
+#        }
+#    }
+    return $quoted_id;
+    # quote_identifier  DBI.pm
+}
+
+
 sub quote_table {
     my ( $sf, $table_info ) = @_;
     my @idx;
@@ -322,35 +350,13 @@ sub quote_table {
     else {
         @idx = ( 2 );
     }
-    if ( $sf->{o}{G}{quote_identifiers} ) {
-        return $sf->{d}{dbh}->quote_identifier( @{$table_info}[@idx] );
-    }
-    else {
-        # if @idx with catalog (0,1,2): write code which handles catalog (see `quote_identifier`).
-        return join( '.', grep { length } @{$table_info}[@idx] );
-    }
-}
-
-
-sub quote_col_qualified {
-    my ( $sf, $col_identifier_parts ) = @_;
-    if ( $sf->{o}{G}{quote_identifiers} ) {
-        return $sf->{d}{dbh}->quote_identifier( @$col_identifier_parts );
-    }
-    else {
-        return join( '.', grep { length } @$col_identifier_parts );
-    }
+    return $sf->prepare_identifier( @{$table_info}[@idx] );
 }
 
 
 sub quote_cols {
     my ( $sf, $cols ) = @_;
-    if ( $sf->{o}{G}{quote_identifiers} ) {
-        return [ map { $sf->{d}{dbh}->quote_identifier( $_ ) } @$cols ];
-    }
-    else {
-        return [ @$cols ];
-    }
+    return [ map { $sf->prepare_identifier( $_ ) } @$cols ];
 }
 
 
