@@ -103,12 +103,12 @@ sub _options {
             { name => '_csv_in_options',    text => "- CSV options in b",   section => 'csv_in' },
             { name => '_split_config',      text => "- Settings 'split'",   section => 'split'  },
             { name => '_input_filter',      text => "- Input filter",       section => 'insert' },
-            { name => '_empty_to_null',     text => "- Empty to NULL",      section => 'insert' },
+            { name => '_empty_to_null',     text => "- Empty to Null",      section => 'insert' },
             { name => '_file_encoding_in',  text => "- File encoding in",   section => 'insert' },
             { name => 'history_dirs',       text => "- Directory history",  section => 'insert' },
             { name => '_file_filter',       text => "- File filter",        section => 'insert' },
-            { name => '_show_hidden_files', text => "- Show hidden files",  section => 'insert' },
-            { name => '_data_source_type',  text => "- Menu 'data source'", section => 'insert' },
+            { name => '_show_hidden_files', text => "- Hidden files",       section => 'insert' },
+            { name => '_data_source_type',  text => "- Source type",        section => 'insert' },
         ],
         group_export => [
             { name => 'export_dir',         text => "- Destination folder", section => 'export'  },
